/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/* eslint-disable  */
import React from 'react';
import { CategoricalColorNamespace } from '@superset-ui/core';
import Echart from './components/Echart';
import _ from 'lodash';
import { registerMap } from 'echarts'; // 注册地图
// registerMap('china', require('./components/china.json'))
// 世界地图json

var mapJson = require('./components/world.json'); // 注册世界地图


registerMap('world', mapJson); // 加载三字码

var thirdCode = require('./components/thirdCode.json'); // 加载三字码的站点与经纬度的映射关系


var addressLat = require('./components/address.json'); // 散点图数据整理


function getScatterList(data, startFrom, endTo, colorScale, sliceId) {
  var station = Array.from(new Set(data.map(v => [_.get(v, startFrom), _.get(v, endTo)]).flat()));
  var list = station.map(v => {
    var stationName = _.get(thirdCode, v);

    var stationValue = _.get(addressLat, v);

    if (stationName && stationValue) {
      return {
        name: stationName,
        value: stationValue,
        'itemStyle': {
          'normal': {
            'color': colorScale(stationName, sliceId)
          },
          'emphasis': {
            'areaColor': '#2B91B7'
          }
        }
      };
    } else {
      return undefined;
    }
  }).filter(v => v !== undefined);
  return list;
} // 航线数据整理


function getlineList(data, startFrom, endTo, colorScale, sliceId, columns, metrics) {
  var list = [];
  var midFromName = '';
  var midToName = '';
  var midFromValue = '';
  var midToValue = '';
  var midObj = {};
  data.forEach((v, k) => {
    midFromName = _.get(thirdCode, _.get(v, startFrom));
    midToName = _.get(thirdCode, _.get(v, endTo));
    midFromValue = _.get(addressLat, _.get(v, startFrom));
    midToValue = _.get(addressLat, _.get(v, endTo));
    midObj = {
      fromName: midFromName,
      toName: midToName,
      coords: [midFromValue, midToValue],
      value: 100,
      lineStyle: {
        normal: {
          'color': colorScale(midFromName, sliceId),
          'width': 1,
          'opacity': 0.6,
          'curveness': 0.2
        }
      }
    };
    midObj = _.assign({}, midObj, _.pick(v, columns), _.pick(v, metrics));

    if (midFromName && midFromValue && midToName && midToValue) {
      list.push(midObj);
    }
  });
  return list;
}

export default function SupersetPluginChartMap(props) {
  var {
    data,
    height,
    width,
    startFrom,
    endTo,
    columns,
    metrics,
    isScale,
    areaColor,
    mapLine,
    colorScheme,
    sliceId
  } = props; // 颜色系列配置

  var colorScale = CategoricalColorNamespace.getScale(colorScheme); // 散点图数据

  var seriesScatterList = getScatterList(data, startFrom, endTo, colorScale, sliceId); // 航线图数据

  var seriesLineList = getlineList(data, startFrom, endTo, colorScale, sliceId, columns, metrics); // TODO 设置options

  var echartOptions = {
    // hover效果
    tooltip: {
      show: true,
      formatter: function formatter(params) {
        return params.name + '站点';
      }
    },
    'geo': {
      map: 'world',
      // 是否可以滚动
      zoom: 5,
      // 中国中心的经纬度
      center: [104.2978515625, 35.8544921875],
      regions: [{
        name: '台湾',
        emphasis: {
          itemStyle: {
            areaColor: '#DE2910'
          }
        },
        selected: true
      }, {
        name: '澳门',
        emphasis: {
          itemStyle: {
            areaColor: '#DE2910'
          }
        },
        selected: true
      }, {
        name: '香港',
        emphasis: {
          itemStyle: {
            areaColor: '#DE2910'
          }
        },
        selected: true
      }],
      'label': {
        'emphasis': {
          'show': true,
          'color': '#fff'
        }
      },
      'roam': isScale,
      'itemStyle': {
        'normal': {
          'areaColor': areaColor,
          'borderColor': mapLine,
          'borderWidth': 1
        },
        'emphasis': {
          'areaColor': '#2B91B7'
        }
      }
    },
    // color: yellowList,
    'series': [// 地图配置
    {
      name: '中国地图',
      type: 'map',
      mapType: 'china',
      geoIndex: 0,
      label: {
        normal: {
          show: true
        },
        emphasis: {
          show: true
        }
      },
      data: require('./components/province.json') // 默认是省级数据

    }, {
      // 'name': '站点',
      'type': 'effectScatter',
      'coordinateSystem': 'geo',
      'zlevel': 2,
      'rippleEffect': {
        'brushType': 'stroke'
      },
      'label': {
        'normal': {
          'show': true,
          'position': 'right',
          'formatter': '{b}'
        }
      },
      tooltip: {
        show: true,
        formatter: function formatter(params) {
          // TODO XXX
          return params.name + '站点';
        }
      },
      'data': seriesScatterList
    }, {
      'name': '航线',
      'type': 'lines',
      'zlevel': 1,
      'effect': {
        'show': true,
        'period': 6,
        'trailLength': 0.7,
        'color': 'red',
        'symbolSize': 3
      },
      'lineStyle': {
        'normal': {
          'color': '#ffa022',
          'width': 0,
          'curveness': 0.2
        }
      },
      'data': seriesLineList
    }, {
      'name': '航线',
      'type': 'lines',
      'zlevel': 2,
      'symbol': ['none', 'arrow'],
      'symbolSize': 10,
      'effect': {
        'show': true,
        'period': 6,
        'trailLength': 0,
        'symbol': 'path://M1705.06,1318.313v-89.254l-319.9-221.799l0.073-208.063c0.521-84.662-26.629-121.796-63.961-121.491c-37.332-0.305-64.482,36.829-63.961,121.491l0.073,208.063l-319.9,221.799v89.254l330.343-157.288l12.238,241.308l-134.449,92.931l0.531,42.034l175.125-42.917l175.125,42.917l0.531-42.034l-134.449-92.931l12.238-241.308L1705.06,1318.313z',
        'symbolSize': 15
      },
      tooltip: {
        formatter: function formatter(params) {
          // 航线上的hover
          var data = _.get(params, 'data'); // const columsobj =


          var tipStr = data.fromName + " - " + data.toName;

          var otherObj = _.assign({}, _.pick(data, columns), _.pick(data, metrics));

          for (var key in otherObj) {
            tipStr = tipStr + "<br/>" + key + ": " + otherObj[key];
          }

          return tipStr;
        }
      },
      'data': seriesLineList
    }]
  };
  return /*#__PURE__*/React.createElement(Echart, {
    height: height,
    width: width,
    echartOptions: echartOptions
  });
}